@@ -11,8 +11,18 @@
 #' cutAtMultSites(c(tmp,"ojioRij"),c("R","K"))
 #' @export
 cutAtMultSites <- function(y,cutAt) {
-  for(i in cutAt) {y <- strsplit(y,i); y <- as.character(unlist(sapply(y,.addLetterWoLast,addChr=i)))}; y}
+  for(i in cutAt) {y <- strsplit(y,i); y <- as.character(unlist(sapply(y, .addLetterWoLast, addChr=i)))}; y}
 
+#' Add letter to all elements but not last
+#'
+#' This function allows to add 'addChr' to all entries, without the last entry
+#' 
+#' @param x (character) main input
+#' @param addChr (character)
+#' @return This function returns a modified character vector
+#' @seealso  \code{\link[base]{paste}}; used in \code{\link{cutAtMultSites}}
+#' @examples
+#' .addLetterWoLast(c("abc","efgh"),"Z")
 #' @export  
-.addLetterWoLast <- function(x,addChr) paste(x,rep(c(addChr,""),c(length(x)-1,1)),sep="")            # add 'addChr' to all entries wo last entry  
+.addLetterWoLast <- function(x, addChr) paste0(x,rep(c(addChr,""),c(length(x)-1,1)))            # add 'addChr' to all entries wo last entry  
   
